==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/util/NamedInputStream.h <==
// public class gnu.xml.libxmlj.util.NamedInputStream

// class file dependencies
// @dep_class c07aa5914a0c452d gnu_xml_libxmlj_util_NamedInputStream
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_gnu_xml_libxmlj_util_NamedInputStream_H_
#define _JC_gnu_xml_libxmlj_util_NamedInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_util_NamedInputStream$sub_refs	_jc_gnu_xml_libxmlj_util_NamedInputStream$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_util_NamedInputStream$sub_nonrefs	_jc_gnu_xml_libxmlj_util_NamedInputStream$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_util_NamedInputStream$refs	_jc_gnu_xml_libxmlj_util_NamedInputStream$refs;
typedef struct _jc_gnu_xml_libxmlj_util_NamedInputStream$nonrefs	_jc_gnu_xml_libxmlj_util_NamedInputStream$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_util_NamedInputStream$object	_jc_gnu_xml_libxmlj_util_NamedInputStream$object;

typedef struct _jc_gnu_xml_libxmlj_util_NamedInputStream$fields_struct	_jc_gnu_xml_libxmlj_util_NamedInputStream$fields_struct;
typedef const struct _jc_gnu_xml_libxmlj_util_NamedInputStream$vmethods	_jc_gnu_xml_libxmlj_util_NamedInputStream$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_util_NamedInputStream$vtable	_jc_gnu_xml_libxmlj_util_NamedInputStream$vtable;
typedef const struct _jc_gnu_xml_libxmlj_util_NamedInputStream$vtype	_jc_gnu_xml_libxmlj_util_NamedInputStream$vtype;

// Class fields structure
struct _jc_gnu_xml_libxmlj_util_NamedInputStream$fields_struct {
	jint	DETECT__5fBUFFER__5fSIZE;
};
extern _jc_gnu_xml_libxmlj_util_NamedInputStream$fields_struct _jc_gnu_xml_libxmlj_util_NamedInputStream$class_fields;

// Constructors
extern void _jc_gnu_xml_libxmlj_util_NamedInputStream$method$_init$63c48848ef8cae69(_jc_env *, struct _jc_gnu_xml_libxmlj_util_NamedInputStream$object *, struct _jc_java_lang_String$object *, struct _jc_java_io_InputStream$object *, jint);

// Virtual methods
extern _jc_byte_array *_jc_gnu_xml_libxmlj_util_NamedInputStream$method$getDetectBuffer$b8dcc61321c49b7d(_jc_env *, struct _jc_gnu_xml_libxmlj_util_NamedInputStream$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_util_NamedInputStream$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_gnu_xml_libxmlj_util_NamedInputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_util_NamedInputStream$method_info$getDetectBuffer$b8dcc61321c49b7d;
extern _jc_method _jc_gnu_xml_libxmlj_util_NamedInputStream$method_info$getName$bec186f2ce7e1882;

// Static methods
extern void _jc_gnu_xml_libxmlj_util_NamedInputStream$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_util_NamedInputStream$vmethods {
	_jc_byte_array	*(*getDetectBuffer$b8dcc61321c49b7d)(_jc_env *, struct _jc_gnu_xml_libxmlj_util_NamedInputStream$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_gnu_xml_libxmlj_util_NamedInputStream$object *);
};

// Vtable
struct _jc_gnu_xml_libxmlj_util_NamedInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_gnu_xml_libxmlj_util_NamedInputStream$vmethods	gnu_xml_libxmlj_util_NamedInputStream;
};

// Vtype
struct _jc_gnu_xml_libxmlj_util_NamedInputStream$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_util_NamedInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_util_NamedInputStream$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_util_NamedInputStream$refs {
    _jc_gnu_xml_libxmlj_util_NamedInputStream$sub_refs	gnu_xml_libxmlj_util_NamedInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_util_NamedInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_util_NamedInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_gnu_xml_libxmlj_util_NamedInputStream$sub_nonrefs	gnu_xml_libxmlj_util_NamedInputStream;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_util_NamedInputStream$object {
	_jc_gnu_xml_libxmlj_util_NamedInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_util_NamedInputStream$vtype	*vtype;
	_jc_gnu_xml_libxmlj_util_NamedInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_util_NamedInputStream$vtype _jc_gnu_xml_libxmlj_util_NamedInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_util_NamedInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_util_NamedInputStream$class_object;

#endif	/* _JC_gnu_xml_libxmlj_util_NamedInputStream_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/util/NamedInputStream.h <==
// public class gnu.xml.libxmlj.util.NamedInputStream

// class file dependencies
// @dep_class c07aa5914a0c452d gnu_xml_libxmlj_util_NamedInputStream
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_gnu_xml_libxmlj_util_NamedInputStream_H_
#define _JC_gnu_xml_libxmlj_util_NamedInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_util_NamedInputStream$sub_refs	_jc_gnu_xml_libxmlj_util_NamedInputStream$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_util_NamedInputStream$sub_nonrefs	_jc_gnu_xml_libxmlj_util_NamedInputStream$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_util_NamedInputStream$refs	_jc_gnu_xml_libxmlj_util_NamedInputStream$refs;
typedef struct _jc_gnu_xml_libxmlj_util_NamedInputStream$nonrefs	_jc_gnu_xml_libxmlj_util_NamedInputStream$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_util_NamedInputStream$object	_jc_gnu_xml_libxmlj_util_NamedInputStream$object;

typedef struct _jc_gnu_xml_libxmlj_util_NamedInputStream$fields_struct	_jc_gnu_xml_libxmlj_util_NamedInputStream$fields_struct;
typedef const struct _jc_gnu_xml_libxmlj_util_NamedInputStream$vmethods	_jc_gnu_xml_libxmlj_util_NamedInputStream$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_util_NamedInputStream$vtable	_jc_gnu_xml_libxmlj_util_NamedInputStream$vtable;
typedef const struct _jc_gnu_xml_libxmlj_util_NamedInputStream$vtype	_jc_gnu_xml_libxmlj_util_NamedInputStream$vtype;

// Class fields structure
struct _jc_gnu_xml_libxmlj_util_NamedInputStream$fields_struct {
	jint	DETECT__5fBUFFER__5fSIZE;
};
extern _jc_gnu_xml_libxmlj_util_NamedInputStream$fields_struct _jc_gnu_xml_libxmlj_util_NamedInputStream$class_fields;

// Constructors
extern void _jc_gnu_xml_libxmlj_util_NamedInputStream$method$_init$63c48848ef8cae69(_jc_env *, struct _jc_gnu_xml_libxmlj_util_NamedInputStream$object *, struct _jc_java_lang_String$object *, struct _jc_java_io_InputStream$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_byte_array *_jc_gnu_xml_libxmlj_util_NamedInputStream$method$getDetectBuffer$b8dcc61321c49b7d(_jc_env *, struct _jc_gnu_xml_libxmlj_util_NamedInputStream$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_util_NamedInputStream$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_gnu_xml_libxmlj_util_NamedInputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_util_NamedInputStream$method_info$getDetectBuffer$b8dcc61321c49b7d;
extern _jc_method _jc_gnu_xml_libxmlj_util_NamedInputStream$method_info$getName$bec186f2ce7e1882;

// Static methods
extern void _jc_gnu_xml_libxmlj_util_NamedInputStream$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_util_NamedInputStream$vmethods {
	_jc_byte_array	*(*getDetectBuffer$b8dcc61321c49b7d)(_jc_env *, struct _jc_gnu_xml_libxmlj_util_NamedInputStream$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_gnu_xml_libxmlj_util_NamedInputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_libxmlj_util_NamedInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_gnu_xml_libxmlj_util_NamedInputStream$vmethods	gnu_xml_libxmlj_util_NamedInputStream;
};

// Vtype
struct _jc_gnu_xml_libxmlj_util_NamedInputStream$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_util_NamedInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_util_NamedInputStream$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_util_NamedInputStream$refs {
    _jc_gnu_xml_libxmlj_util_NamedInputStream$sub_refs	gnu_xml_libxmlj_util_NamedInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_util_NamedInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_util_NamedInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_gnu_xml_libxmlj_util_NamedInputStream$sub_nonrefs	gnu_xml_libxmlj_util_NamedInputStream;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_util_NamedInputStream$object {
	_jc_gnu_xml_libxmlj_util_NamedInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_util_NamedInputStream$vtype	*vtype;
	_jc_gnu_xml_libxmlj_util_NamedInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_util_NamedInputStream$vtype _jc_gnu_xml_libxmlj_util_NamedInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_util_NamedInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_util_NamedInputStream$class_object;

#endif	/* _JC_gnu_xml_libxmlj_util_NamedInputStream_H_ */
